==> react-magic-hat-0.2.6.tgz: package/README.md <==
# React Magic Hat

> A kind of UI Technique

React implementation of what I call the **Magic Hat UI technique**.

<p align="center"> 
  <img src="https://albinotonnina.github.io/magic-hat-technique/demo.gif">
</p>

## Features

🚀 Blazing fast (\[\*](https://twitter.com/acdlite/status/974390255393505280)) : 60+ FPS hardware-accelerated CSS transforms, using the [FLIP technique](https://aerotwist.com/blog/flip-your-animations/#the-general-approach)

⚡️Extra smooth:

🎈 Lightweight: `6kb`

## Table of Contents

* [Background](#background)
* [Install](#install)
* [Usage](#usage)
* [API](#api)
* [Example](#example)
* [Maintainers](#maintainers)
* [Contribute](#contribute)
* [License](#license)

## Background

Here why this exists./

## Install

```
yarn add stacky-ui
```

## Usage

```jsx
import {Stacky} from 'stacky-ui'
import ComponentA from 'components'

const Layout = () => (
  <div>
    <Stacky renderFrame={() => <ComponentA />} />
  </div>
)
```

## API

### Prop Types

| Property         | Type     | Required? | Description                                                                          |
| :--------------- | :------- | :-------: | :----------------------------------------------------------------------------------- |
| renderFrame      | Function |     ✓     | Callback invoked when rendering the visible pages. [Documentation](#renderframepage) |
| onStartAnimation | Function |           | text                                                                                 |
| onEndAnimation   | Function |           | text                                                                                 |
| flipMoveOptions  | Function |           | text                                                                                 |
| singleFrame      | Boolean  |           | By default show two pages. Set this to `true` to show only one.                      |
| moveSeed         | String   |           | Change this to trigger animation on every visible page                               |

### renderFrame(page)

```jsx
import getComponentById from './your-components'

const renderFrame = pageObject => {
  const {
    id, // 'my-component-id'
    page, // 4
    activePage, // 5
    state, // { propWePassed: 42, otherProp: 24 }
    actions // see next paragraph for the actions methods
  } = pageObject

  const Page = getComponentById(id) // return a Component

  return <Page {...state} {...actions} />
}
```

### {actions} API

| Method                                         | Description                                                   |
| :--------------------------------------------- | :------------------------------------------------------------ |
| setCurrentFrame(props:object)                  | Set props on the current page                                 |
| getCurrentFrame():object                       | Get props of the current page                                 |
| closeCurrentFrame()                            | Close the current page                                        |
| setNextFrame(id:string, props:object )         | Set (adds if missing) the next page and optionally pass props |
| getNextFrame()                                 | Get props of the next page                                    |
| closeNextFrame()                               | Close the next page                                           |
| setFrame(page:number, id:string, props:object) |                                                               |
| getFrame(page:number):props                    |                                                               |
| closeFrame()                                   |                                                               |

## Example

```jsx
code
```

## Maintainers

[@albinotonnina](https://github.com/albinotonnina)

## Contribute

PRs accepted.

## License

MIT © 2018 Albino Tonnina

==> react-magic-hat-0.2.7.tgz: package/README.md <==
# React Magic Hat 🎩✨

> A kind of UI technique

React implementation of what I call the [**Magic Hat UI technique**](https://medium.com/@albinotonnina/magic-hat-technique-408a3fa590bb).

<p align="center"> 
  <img src="https://albinotonnina.github.io/magic-hat-technique/demo.gif">
</p>

## Features

⚡🚀 [Blazing fast](https://twitter.com/acdlite/status/974390255393505280). 60+ FPS hardware-accelerated CSS transforms, using the FLIP technique. Fluid and performant.

🎈Extra light, only 6.5kb

🧘‍Flexible, stateful or stateless (you get both components) it’s UI-less, you do the styling here.

🎛 Highly configurable

## Table of Contents

* [Background](#background)
* [Install](#install)
* [Usage](#usage)
* [API](#api)
* [Example](#example)
* [Maintainers](#maintainers)
* [Contribute](#contribute)
* [License](#license)

## Background

The Magic Hat is a technique with the purpose of reducing the the total amount of mental effort that is required to complete a task involving processing of information, in short cognitive load, by limiting the amount of UI on the screen in favour of a runtime like linked list of sequential self sufficient UIs called MUVs (Minimum Usable Views)
It's called like this because in a view the user can pick the next thing to put on screen. It’s pretty much it.

[Open the article on medium.com](https://medium.com/@albinotonnina/magic-hat-technique-408a3fa590bb)

## Install

```
yarn add react-magic-hat
```

## Usage

```jsx
import YourMagicContainer from 'react-magic-hat'
import ComponentA, {id as CompA} from 'components'
import ComponentB from 'components'

const renderFrame = ({id, actions}) => {
  const Component = id === CompA ? ComponentA : ComponentB

  return <Component {...props} {...actions} />
}

const Layout = () => (
  <div>
    <YourMagicContainer renderFrame={renderFrame} />
  </div>
)
```

## API

### Prop Types

| Property         | Type     | Required? | Description                                                                          |
| :--------------- | :------- | :-------: | :----------------------------------------------------------------------------------- |
| renderFrame      | Function |     ✓     | Callback invoked when rendering the visible pages. [Documentation](#renderframepage) |
| onStartAnimation | Function |           | text                                                                                 |
| onEndAnimation   | Function |           | text                                                                                 |
| flipMoveOptions  | Function |           | text                                                                                 |
| singleFrame      | Boolean  |           | By default show two pages. Set this to `true` to show only one.                      |
| moveSeed         | String   |           | Change this to trigger animation on every visible page                               |

### renderFrame(pageObject)

```jsx
import getComponentById from './your-components'

const renderFrame = pageObject => {
  const {
    id, // 'my-component-id'
    page, // 4
    activePage, // 5
    state, // { propWePassed: 42, otherProp: 24 }
    actions // see next paragraph for the actions methods
  } = pageObject

  const Page = getComponentById(id) // return a Component, do it whatever you like it

  return <Page {...state} {...actions} />
}
```

### {actions} API

| Method                                         | Description                                                   |
| :--------------------------------------------- | :------------------------------------------------------------ |
| setCurrentFrame(props:object)                  | Set props on the current page                                 |
| getCurrentFrame():object                       | Get props of the current page                                 |
| closeCurrentFrame()                            | Close the current page                                        |
| setNextFrame(id:string, props:object )         | Set (adds if missing) the next page and optionally pass props |
| getNextFrame()                                 | Get props of the next page                                    |
| closeNextFrame()                               | Close the next page                                           |
| setFrame(page:number, id:string, props:object) |                                                               |
| getFrame(page:number):props                    |                                                               |
| closeFrame()                                   |                                                               |

## Examples

Basic demo on codesandbox

https://codesandbox.io/s/r4v7onrpop

React-create-app Demo

https://albinotonnina.github.io/magic-hat-technique/

## Maintainers

[@albinotonnina](https://github.com/albinotonnina)

## Contribute

PRs accepted.

## License

MIT © 2018 Albino Tonnina
